@@ -537,7 +537,7 @@ function(input, output, session) {
     if (input$evaltype == "lm") {
       first = paste0(c(first,
                        "<code style=\"color:#468449\"># Evaluating Design:</code><br>",
-                       "eval_design(RunMatrix = design, <br>", rep("&nbsp;", 12),
+                       "eval_design(design = design, <br>", rep("&nbsp;", 12),
                        "model = ", regularmodelstring(), ", <br>", rep("&nbsp;", 12),
                        "alpha = ", input$alpha), collapse = "")
       if (isblockingtext()) {
@@ -585,7 +585,7 @@ function(input, output, session) {
     if (input$evaltype == "glm") {
       first = paste0(c(first,
                        "<code style=\"color:#468449\"># Evaluating (Monte Carlo) Design:</code><br>",
-                       "eval_design_mc(RunMatrix = design, <br>", rep("&nbsp;", 15),
+                       "eval_design_mc(design = design, <br>", rep("&nbsp;", 15),
                        "model = ", regularmodelstring(), ", <br>", rep("&nbsp;", 15),
                        "alpha = ", input$alpha), collapse = "")
       if (isblockingtext()) {
@@ -646,7 +646,7 @@ function(input, output, session) {
     if (input$evaltype == "surv") {
       first = paste0(c(first,
                        "<code style=\"color:#468449\"># Evaluating (Monte Carlo Survival) Design:</code><br>",
-                       "eval_design_survival_mc(RunMatrix = design, <br>", rep("&nbsp;", 24),
+                       "eval_design_survival_mc(design = design, <br>", rep("&nbsp;", 24),
                        "model = ", as.character(as.formula(input$model)), ", <br>", rep("&nbsp;", 24),
                        "alpha = ", input$alpha), collapse = "")
       if (input$nsim_surv != 1000) {
@@ -872,7 +872,7 @@ function(input, output, session) {
   powerresults = reactive({
     input$evalbutton
     if (evaluationtype() == "lm") {
-      eval_design(RunMatrix = isolate(runmatrix()),
+      eval_design(design = isolate(runmatrix()),
                   model = as.formula(isolate(input$model)),
                   alpha = isolate(input$alpha),
                   blocking = isblocking(),
@@ -889,7 +889,7 @@ function(input, output, session) {
       }
       if (isolate(input$parallel_eval_glm)) {
         showNotification("Simulating (no progress bar with multicore on):", type = "message")
-        eval_design_mc(RunMatrix = isolate(runmatrix()),
+        eval_design_mc(design = isolate(runmatrix()),
                        model = isolate(as.formula(input$model)),
                        alpha = isolate(input$alpha),
                        blocking = isolate(isblocking()),
@@ -902,7 +902,7 @@ function(input, output, session) {
                        advancedoptions = list(GUI = TRUE))
       } else {
         withProgress(message = ifelse(isolate(isblocking()), "Simulating (with REML):", "Simulating:"), value = 0, min = 0, max = 1, expr = {
-          eval_design_mc(RunMatrix = isolate(runmatrix()),
+          eval_design_mc(design = isolate(runmatrix()),
                          model = isolate(as.formula(input$model)),
                          alpha = isolate(input$alpha),
                          blocking = isolate(isblocking()),
@@ -927,7 +927,7 @@ function(input, output, session) {
       }
       if (isolate(input$parallel_eval_surv)) {
         showNotification("Simulating (no progress bar with multicore on):", type = "message")
-        eval_design_survival_mc(RunMatrix = isolate(runmatrix()),
+        eval_design_survival_mc(design = isolate(runmatrix()),
                                 model = isolate(as.formula(input$model)),
                                 alpha = isolate(input$alpha),
                                 nsim = isolate(input$nsim),
@@ -939,7 +939,7 @@ function(input, output, session) {
                                 parallel = isolate(input$parallel_eval_surv))
       } else {
         withProgress(message = "Simulating:", value = 0, min = 0, max = 1, expr = {
-          eval_design_survival_mc(RunMatrix = isolate(runmatrix()),
+          eval_design_survival_mc(design = isolate(runmatrix()),
                                   model = isolate(as.formula(input$model)),
                                   alpha = isolate(input$alpha),
                                   nsim = isolate(input$nsim),
